@@ -47,8 +47,6 @@
 #include <KIO/PreviewJob>
 #include <KPluginFactory>
 
-#include <kio_version.h>
-
 #include <limits>
 
 #include "imagefilter.h"
@@ -91,7 +89,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 #if defined(Q_OS_WINDOWS)
     SetPriorityClass(GetCurrentProcess(), BELOW_NORMAL_PRIORITY_CLASS);
 #else
-    nice(5);
+    std::ignore = nice(5);
 #endif
 
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
@@ -323,7 +321,7 @@ KIO::WorkerResult ThumbnailProtocol::get(const QUrl &url)
 
 KPluginMetaData ThumbnailProtocol::pluginForMimeType(const QString &mimeType)
 {
-    const QVector<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
+    const QList<KPluginMetaData> plugins = KIO::PreviewJob::availableThumbnailerPlugins();
     for (const KPluginMetaData &plugin : plugins) {
         if (plugin.supportsMimeType(mimeType)) {
             return plugin;
@@ -428,12 +426,16 @@ void ThumbnailProtocol::drawPictureFrame(QPainter *painter,
 QImage ThumbnailProtocol::thumbForDirectory(const QString &directory)
 {
     QImage img;
+    KFileItem item(QUrl::fromLocalFile(directory));
+
+    const KConfigGroup globalConfig(KSharedConfig::openConfig(), QStringLiteral("PreviewSettings"));
+    m_maxFileSize = !item.isSlow() ? globalConfig.readEntry("MaximumSize", std::numeric_limits<KIO::filesize_t>::max())
+                                       : globalConfig.readEntry<KIO::filesize_t>("MaximumRemoteSize", 0);
+
     if (m_propagationDirectories.isEmpty()) {
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
-        const KConfigGroup globalConfig(KSharedConfig::openConfig(), QStringLiteral("PreviewSettings"));
         const QStringList propagationDirectoriesList = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS");
         m_propagationDirectories = QSet<QString>(propagationDirectoriesList.begin(), propagationDirectoriesList.end());
-        m_maxFileSize = globalConfig.readEntry("MaximumSize", std::numeric_limits<qint64>::max());
     }
 
     const int tiles = 2; // Count of items shown on each dimension
@@ -444,7 +446,6 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString &directory)
     // Provide a fallback solution for other iconsets (e. g. draw folder
     // only as small overlay, use no margins)
 
-    KFileItem item(QUrl::fromLocalFile(directory));
     const int extent = qMin(m_width, m_height);
     QPixmap folder = QIcon::fromTheme(item.iconName()).pixmap(extent);
     folder.setDevicePixelRatio(m_devicePixelRatio);
@@ -521,7 +522,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString &directory)
                 continue;
             }
 
-            auto fileSize = dir.fileInfo().size();
+            const auto fileSize = KIO::filesize_t(dir.fileInfo().size());
             if ((fileSize == 0) || (fileSize > m_maxFileSize)) {
                 // don't create thumbnails for files that exceed
                 // the maximum set file size or are empty
